--- a/idlefw/plugins/sapidataplugin/inc/sapidataplugin.h Fri Mar 12 15:43:54 2010 +0200
+++ b/idlefw/plugins/sapidataplugin/inc/sapidataplugin.h Mon Mar 15 12:41:53 2010 +0200
@@ -30,6 +30,7 @@
class MAiContentItemIterator;
class CSapiData;
class CGulIcon;
+class CLiwDefaultMap;
/**
* @ingroup group_sapidataplugin
@@ -189,11 +190,15 @@
/**
* RefereshL a specific image of text in the widget
*
* @param aContentType content type
* @param aOperation operation performed
* @return void
*/
- void RefreshL(TDesC& aContentType, TDesC& aOperation);
+ void RefreshL( TDesC& aContentType,
+ TDesC& aOperation,
+ CLiwDefaultMap* aDataMap );
/**
* Is plugin active to publish the data
@@ -189,11 +190,15 @@
* RefereshL a specific image of text in the widget
*
- * @param aContentType content type
- * @param aOperation operation performed
+ * @param aContentType content type
+ * @param aOperation operation performed
+ * @param aDataMap data map if available. Can be NULL.
+ * Ownership NOT transferred.
* @return void
*/